local addonName, NICE = ...; NICE.Main = { }

local NUM_SOUNDFILES = 7
local addonFrame = CreateFrame("FRAME")
local playerName = UnitName("player")
-- list of items being rolled for at the moment
local _items = {}

--[[plays a random sound effect saying "nice"]]
function NICE.Main.NiceSoundEffect()
  PlaySoundFile("Interface\\AddOns\\Nice\\Sounds\\nice" .. math.random(NUM_SOUNDFILES) .. ".ogg", "SFX")
end

--[[posts "nice" to party or raid chat]]
function NICE.Main.NiceChatMessage()
  if(IsInRaid()) then
    SendChatMessage("nice", "RAID")
  elseif(IsInGroup()) then
    SendChatMessage("nice", "PARTY")
  end
end

--[[plays sound file saying nice and posts "nice" to party or raid chat]]
function NICE.Main.Nice()
  if(Nice_Settings.SoundEffectsEnabled) then NICE.Main.NiceSoundEffect() end
  if(Nice_Settings.ChatMessagesEnabled) then NICE.Main.NiceChatMessage() end
end

--[["ADDON_LOADED" event handler: initializes SavedVariables on first load]]
local function AddOnLoaded(addonName)
  if (addonName == "Nice") then NICE.Settings.InitSettings() end
end

--[[handles loot messages that are a roll on an item: returns true if loot message was a roll]]
local function LootRollHandler(lootMessage)
  -- LOOT_ROLL_ROLLED_GREED = "Greed Roll - %d for %s by %s"
  -- LOOT_ROLL_ROLLED_NEED = "Need Roll - %d for %s by %s"
  local _, _, roll, item, player = string.find(lootMessage, "(%d+) for (.+) by (%a+)");

  -- lootMessage was a loot roll
  if(roll == "69" and item ~= nil and player ~= nil) then
    if(Nice_Settings.OnlyWinningRolls) then
      -- add item to list of _items currently being rolled for
      if(_items[item] == nil) then _items[item] = {} end
      -- add player to list of players of item who rolled a 69
      table.insert(_items[item], player)
    else NICE.Main.Nice() end
  end

  return roll ~= nil
end

--[[handles loot messages that are a player winning an item]]
local function LootWonHandler(lootMessage)
  -- LOOT_ROLL_WON = "%s won: %s"
  -- LOOT_ROLL_YOU_WON = "You won: %s"
  local _, _, player, item = string.find(lootMessage, "(%a+) won: (.+)")
  if(player == "You") then player = playerName end

  -- Nice if player won with 69
  if(player ~= nil and _items[item] ~= nil) then
    -- check if winning player rolled 69 for item
    for i,v in ipairs(_items[item]) do
      if(v == player) then
        NICE.Main.Nice()
        break
      end
    end
    -- item roll over, remove item, nice
    _items[item] = nil
  end
end

--[["CHAT_MSG_LOOT" event handler: triggers Nice if a player won a loot roll with a 69]]
local function ChatMessageLoot(lootMessage)
  if(not LootRollHandler(lootMessage) and Nice_Settings.OnlyWinningRolls) then LootWonHandler(lootMessage) end
end

--[["CHAT_MSG_SYSTEM" event handler: triggers Nice if player /roll rolled a 69 without setting lower and upper bound to 69]]
local function ChatMessageSystem(systemMessage)
  -- RANDOM_ROLL_RESULT = "%s rolls %d (%d-%d)"
  local _, _, player, roll, bounds = string.find(systemMessage, "(%a+) rolls (%d+) (.+)");
  if(roll == "69" and bounds ~= "(69-69)") then NICE.Main.Nice() end
end

function addonFrame:OnEvent(event, ...)
  if(event == "ADDON_LOADED") then AddOnLoaded(...) end
  if(event == "CHAT_MSG_SYSTEM" and Nice_Settings.SlashRollsEnabled) then ChatMessageSystem(...) end
  if(event == "CHAT_MSG_LOOT" and Nice_Settings.LootRollsEnabled) then ChatMessageLoot(...) end
end

local function SlashCommandHandler(cmdOptions)
  if(string.len(cmdOptions) == 0) then NICE.Settings.ShowSettingsFrame() end
end

-- addon frame
addonFrame:RegisterEvent("ADDON_LOADED")
addonFrame:RegisterEvent("CHAT_MSG_LOOT")
addonFrame:RegisterEvent("CHAT_MSG_SYSTEM")
addonFrame:SetScript("OnEvent", addonFrame.OnEvent)

-- slash command
SLASH_NICE1 = "/nice"
SlashCmdList["NICE"] = SlashCommandHandler;
