local addonName, NICE = ...; NICE.Settings = { }

-- UI elements
local settingsFrame, niceButton, closeButton, _lootRollsEnabledCB, _onlyWinningRollsCB, _slashRollsEnabledCB, _soundEffectsEnabledCB, _chatMessagesEnabledCB

local DefaultSettings = {
  LootRollsEnabled = true,
  OnlyWinningRolls = true,
  SlashRollsEnabled = true,
  SoundEffectsEnabled = true,
  ChatMessagesEnabled = true
}

--[[saves addon settings]]
local function SaveSettings()
	if(Nice_Settings == nil ) then Nice_Settings = { } end
  Nice_Settings.LootRollsEnabled = _lootRollsEnabledCB:GetChecked()
  Nice_Settings.OnlyWinningRolls = _onlyWinningRollsCB:GetChecked()
  Nice_Settings.SlashRollsEnabled = _slashRollsEnabledCB:GetChecked()
  Nice_Settings.SoundEffectsEnabled = _soundEffectsEnabledCB:GetChecked()
  Nice_Settings.ChatMessagesEnabled = _chatMessagesEnabledCB:GetChecked()
end

--[[initializes default settings if none are saved]]
function NICE.Settings.InitSettings()
	if (Nice_Settings == nil) then
    Nice_Settings = { }
    Nice_Settings.LootRollsEnabled = DefaultSettings.LootRollsEnabled
    Nice_Settings.OnlyWinningRolls = DefaultSettings.OnlyWinningRolls
    Nice_Settings.SlashRollsEnabled = DefaultSettings.SlashRollsEnabled
    Nice_Settings.SoundEffectsEnabled = DefaultSettings.SoundEffectsEnabled
    Nice_Settings.ChatMessagesEnabled = DefaultSettings.ChatMessagesEnabled
  end
end

local function CreateFontString(parentFrame, x, y, text)
	local fontString = parentFrame:CreateFontString()
	fontString:SetPoint("TOPLEFT", parentFrame, x, y)
	fontString:SetFont(STANDARD_TEXT_FONT, 10, "OUTLINE")
	fontString:SetTextColor(1.0, 0.8, 0.0, 1.0)
	fontString:SetText(text)
end

local function CreateCheckBox(parentFrame, x, y, text, onClickEventHandler)
	local checkBox = CreateFrame("CheckButton", nil, parentFrame, "ChatConfigCheckButtonTemplate");
	checkBox:SetPoint("TOPLEFT", parentFrame, x, y);
	checkBox:SetScript("OnClick", onClickEventHandler)
	CreateFontString(checkBox, 25, -6, text);
	return checkBox
end

local function NiceButtonClicked()
  NICE.Main.NiceSoundEffect()
end

local function CloseButtonClicked()
  settingsFrame:Hide()
end

function NICE.Settings.ShowSettingsFrame()
  if(settingsFrame:IsVisible()) then return end
  _lootRollsEnabledCB:SetChecked(Nice_Settings.LootRollsEnabled)
  _onlyWinningRollsCB:SetChecked(Nice_Settings.OnlyWinningRolls)
  _slashRollsEnabledCB:SetChecked(Nice_Settings.SlashRollsEnabled)
  _soundEffectsEnabledCB:SetChecked(Nice_Settings.SoundEffectsEnabled)
  _chatMessagesEnabledCB:SetChecked(Nice_Settings.ChatMessagesEnabled)
  settingsFrame:Show()
end
-- nice
-- settings frame
settingsFrame = CreateFrame("FRAME", nil, UIParent)
settingsFrame:SetFrameStrata("DIALOG")
settingsFrame:SetWidth(160)
settingsFrame:SetHeight(180)
settingsFrame:SetPoint("CENTER", 0, 0)
settingsFrame:SetBackdrop({
	bgFile = "Interface/DialogFrame/UI-DialogBox-Background",
	edgeFile = "Interface/DialogFrame/UI-DialogBox-Border",
	tile = true, tileSize = 20, edgeSize = 20, insets = { left = 4, right = 4, top = 4, bottom = 4 }
})
settingsFrame:Hide()

-- checkboxes
_lootRollsEnabledCB = CreateCheckBox(settingsFrame, 12, -12, "Enable for Need/Greed", SaveSettings)
_onlyWinningRollsCB = CreateCheckBox(settingsFrame, 30, -37, "Only winnning Rolls", SaveSettings)
_slashRollsEnabledCB = CreateCheckBox(settingsFrame, 12, -62, "Enable for /roll", SaveSettings)
_soundEffectsEnabledCB = CreateCheckBox(settingsFrame, 12, -87, "Enable Sound Effects", SaveSettings)
_chatMessagesEnabledCB = CreateCheckBox(settingsFrame, 12, -112, "Enable Chat Messages", SaveSettings)

-- "Nice" button
niceButton = CreateFrame("Button", nil, settingsFrame, "UIPanelButtonTemplate")
niceButton:SetSize(60, 20)
niceButton:SetText("Nice")
niceButton:SetPoint("BOTTOM", settingsFrame, -35, 15)
niceButton:SetScript("OnClick", NiceButtonClicked)

-- "Close" button
closeButton = CreateFrame("Button", nil, settingsFrame, "UIPanelButtonTemplate")
closeButton:SetSize(60, 20)
closeButton:SetText("Close")
closeButton:SetPoint("BOTTOM", settingsFrame, 35, 15)
closeButton:SetScript("OnClick", CloseButtonClicked)
